@@ -8,16 +8,14 @@ import math
 class Kraken:
 
     # metodo que obtiene la informacion de todos los assets disponibles en Kraken
-
     @classmethod
     def get_asset_info(cls, k):
         assets = k.get_asset_info()
         return assets
 
     # metodo que genera el par tras recibir las dos monedas
-
     @classmethod
-    def set_pair(cls, k, coin1, coin2):
+    def set_pair(cls, coin1, coin2):
         pair = coin1 + coin2
         return pair
 
@@ -64,7 +62,6 @@ class Kraken:
 
     # metodo que recibe el par, y los unixtime y obtiene con esa informacion los trades desde el unixtime
     # de inicio hasta el unixtime del final
-
     @classmethod
     def get_recent_dates(cls, k, pair, from_date, to_date):
         df_trades = pd.DataFrame()
@@ -84,7 +81,6 @@ class Kraken:
         return df_trades
 
     # metodo que hace el calculo del vwap para los precios y volumenes dados
-
     @classmethod
     def calculate_vwap(cls, prices, volumes):
         prices = np.array(prices)
@@ -95,7 +91,6 @@ class Kraken:
             return calculated_vwap
 
     # metodo que recibe los trades para el par indicado y la frecuencia por la que quiere calcular el vwap
-
     @classmethod
     def get_df_vwap(cls, df_trades, frecuency):
         if frecuency == '1 hora':
